@@ -5,7 +5,9 @@ This file is part of minos framework.
 
 Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
 """
-
+from .abc import (
+    MinosHandlerSetup,
+)
 from .command import (
     MinosCommandHandlerDispatcher,
     MinosCommandHandlerServer,
