@@ -11,8 +11,6 @@ from typing import (
 
 from minos.common import (
     Command,
-)
-from minos.common.configuration.config import (
     MinosConfig,
 )
 
@@ -33,5 +31,5 @@ class MinosCommandHandlerDispatcher(MinosHandlerDispatcher):
         try:
             instance = Command.from_avro_bytes(value)
             return True, instance
-        except:
+        except:  # noqa E722
             return False, None
